#!/bin/sh

###########################################################
# Maemo-efl building script
# Enviroment setup functions definitions
#
# Note: var-definitions.sh, log-functions.sh
#       and helper-functions.sh needed.
###########################################################

setup_distro() {
    local target
    local sources_list_file
    local target_conf_file
    local ret
    target=$1
    sources_list_file=$__sbox_path/users/$USER/targets/$target/etc/apt/sources.list
    target_conf_file=$__sbox_path/users/$USER/targets/$target.config
    ret=1

    log_to_file "setup_distro(): Target $target"
    log_to_file "setup_distro(): sources.list file : $sources_list_file"
    log_to_file "setup_distro(): config file: $target_conf_file"

    if [ "x$target" != "x" ] && [ -r $sources_list_file ] && [ -r $target_conf_file ]; then
        # XXX: FIXME Figure out a better way to get the distro string
        __distro=`$__head -1 $sources_list_file | cut -d" " -f3 | cut -d"/" -f1`
        __arch=`$__grep SBOX_CPU= $target_conf_file | cut -d= -f2`
        if [ "x$__arch" == "xi686" ]; then
            __arch="i386"
        elif [ "x$__arch" == "xarm" ]; then
            __arch="armel"
        fi
        __pkg_dir="$__base_pkg_dir/$__distro/$__arch"
        if [ "x$__arch" = "xarmel" ] ; then
            __build_pkg_options="$__common_build_pkg_options -B"
        else
            __build_pkg_options="$__common_build_pkg_options -I.svn -I.git -I.gitignore -I.cvsignore -sa"
        fi
        ret=0
    fi

    if [ $ret -eq 0 ]; then
        log_to_file "setup_distro(): Configuration:"
        log_to_file "setup_distro(): distro...........: $__distro"
        log_to_file "setup_distro(): arch.............: $__arch"
        log_to_file "setup_distro(): build options....: $__build_pkg_options"
        log_to_file "setup_distro(): pkg_dir..........: $__pkg_dir"
    fi

    return $ret
}

setup_sbox() {
    if [ ! -d $__sbox_path ]; then
        error "Invalid scratchbox path: $__sbox_path"
    fi

    __sbox="$__sbox_path/login"
    __sbox_tools_bin_path="$__sbox_path/tools/bin"
    __sbox_sb_conf="$__sbox_tools_bin_path/sb-conf"

    __sbox_maemo3_debian_bin_path="/scratchbox/devkits/maemo3-debian/bin"
    __sbox_dpkg="$__sbox_maemo3_debian_bin_path/dpkg"
    __sbox_dpkg_buildpackage="$__sbox_dpkg-buildpackage"
    __sbox_dpkg_parsechangelog="$__sbox_dpkg-parsechangelog"
    __sbox_dpkg_checkbuilddeps="$__sbox_dpkg-checkbuilddeps"

    __sbox_debian_sarge_bin_path="/scratchbox/devkits/debian-sarge/bin"
    __sbox_dch="$__sbox_debian_sarge_bin_path/dch"

    __sbox_targets=`$__sbox_sb_conf list --targets`
}

change_sbox_target () {
    local target
    target=$1

    $__sbox_sb_conf select $target >> $__output_file 2>&1
    return $?
}

init_checks () {

    if [ x$USER == xroot ]; then
        error "You should not run this script as root"
    fi

    if [ -r /targets/links/scratchbox.config ]; then
        error "You should run this script outside the scratchbox environment."$
    fi
}

setup_dirs () {
    if [ ! -d $__base_pkg_dir ]; then
        msg_begin "Creating base packages dir $__base_pkg_dir"
        $__mkdir -p $__base_pkg_dir
        msg_end $?
    fi

    # Create tmp dir
    if [ ! -d $__tmp_dir ]; then
        msg_begin "Creating tmp dir $__tmp_dir"
        $__mkdir -p $__tmp_dir
        msg_end $?
    fi

}
